@@ -3,5 +3,4 @@ import sys
 from asciimol.app.asciimol import AsciiMol
 
 if __name__ == "__main__":
-    app = AsciiMol()
-    sys.exit(app.run())
+    sys.exit(AsciiMol().run())
